@@ -35,11 +35,13 @@ use warnings;
 use base qw{ PPIx::Regexp::Structure };
 
 use Carp qw{ confess };
+use List::Util qw{ max };
 
-our $VERSION = '0.078';
+our $VERSION = '0.087';
 
 use PPIx::Regexp::Constant qw{
     LITERAL_LEFT_CURLY_ALLOWED
+    VARIABLE_LENGTH_LOOK_BEHIND_INTRODUCED
     @CARP_NOT
 };
 
@@ -67,6 +69,32 @@ sub is_positive {
     return $self->_get_type()->is_positive();
 }
 
+sub perl_version_introduced {
+    my ( $self ) = @_;
+    return( $self->{perl_version_introduced} ||=
+	$self->_perl_version_introduced() );
+}
+
+sub _perl_version_introduced {
+    my ( $self ) = @_;
+    my $ver = max( map { $_->perl_version_introduced() }
+	$self->children() );
+    if ( $ver < VARIABLE_LENGTH_LOOK_BEHIND_INTRODUCED &&
+	!  $self->is_look_ahead()
+    ) {
+	my ( $wid_min, $wid_max ) = $self->raw_width();
+	defined $wid_min
+	    and defined $wid_max
+	    and $wid_min < $wid_max
+	    and $ver = max( $ver, VARIABLE_LENGTH_LOOK_BEHIND_INTRODUCED );
+    }
+    return $ver;
+}
+
+sub width {
+    return ( 0, 0 );
+}
+
 # An un-escaped literal left curly bracket can always follow this
 # element.
 sub __following_literal_left_curly_disallowed_in {
@@ -90,8 +118,9 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
-mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -99,7 +128,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2021 by Thomas R. Wyant, III
+Copyright (C) 2009-2023 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
